==> dde-daemon_3.2.13.3.orig.tar.xz: dde-daemon-3.2.13.3/misc/ts/com.deepin.daemon.accounts.policy/policy_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Para cambiar sus datos de usuario debe autenticarse</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Cambie sus datos de usuario</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Para cambiar datos de usuario debe autenticarse</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Gestione cuentas de usuario</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Se requiere autenticación para habilitar el inicio de sesión automático</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Habilitar inicio de sesión automático</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Se requiere autenticación para desactivar el inicio de sesión automático</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Desactivar inicio de sesión automático</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Se requiere autenticación para habilitar el inicio de sesión sin contraseña</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Habilitar inicio de sesión sin contraseña</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Se requiere autenticación para desactivar el inicio de sesión sin contraseña</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Desactivar inicio de sesión sin contraseña</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.12.52.orig.tar.xz: dde-daemon-5.12.52/misc/ts/com.deepin.daemon.accounts.policy/policy_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Se requiere autenticación para cambiar sus datos de usuario</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Cambiar sus datos de usuario</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Se requiere autenticación para cambiar datos de usuario</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Gestionar cuentas de usuario</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Se requiere autenticación para habilitar el inicio de sesión automático</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Habilitar inicio de sesión automático</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Se requiere autenticación para desactivar el inicio de sesión automático</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Desactivar inicio de sesión automático</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Se requiere autenticación para habilitar el inicio de sesión sin contraseña</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Habilitar inicio de sesión sin contraseña</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Se requiere autenticación para desactivar el inicio de sesión sin contraseña</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Desactivar inicio de sesión sin contraseña</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>Se requiere autenticación para establecer la distribución del teclado</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>Establecer distribución del teclado</translation>
		</message>
	</context>
</TS>
